==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>显示播放状态</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>音轨名显示格式 (例如：qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>显示 --nowplaying 语法</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>Syntax:</source>
        <translation>语法：</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%p - artist</source>
        <translation>%p - 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%a - album</source>
        <translation>%a - 专辑</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%aa - album artist</source>
        <translation>%%aa - 专辑 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%t - title</source>
        <translation>%t - 标题</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%n - track</source>
        <translation>%n - 音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - 两位数音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%g - genre</source>
        <translation>%g - 流派</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%c - comment</source>
        <translation>%c - 备注</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%C - composer</source>
        <translation>%C - 作曲</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%D - disc number</source>
        <translation>%D - 光盘编号</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%f - file name</source>
        <translation>%f - 文件名</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%F - full path</source>
        <translation>%F - 完整路径</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%y - year</source>
        <translation>%y - 年代</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%l - duration</source>
        <translation>%l - 持续时间</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - 条件</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>显示播放状态</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>音轨名显示格式 (例如：qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>显示 --nowplaying 语法</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="87"/>
        <source>Syntax:</source>
        <translation>语法：</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>%p - artist</source>
        <translation>%p - 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%a - album</source>
        <translation>%a - 专辑</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%aa - album artist</source>
        <translation>%%aa - 专辑 艺术家</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%t - title</source>
        <translation>%t - 标题</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%n - track</source>
        <translation>%n - 音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - 两位数音轨</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%g - genre</source>
        <translation>%g - 流派</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%c - comment</source>
        <translation>%c - 备注</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%C - composer</source>
        <translation>%C - 作曲</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%D - disc number</source>
        <translation>%D - 光盘编号</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%f - file name</source>
        <translation>%f - 文件名</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%F - full path</source>
        <translation>%F - 完整路径</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%y - year</source>
        <translation>%y - 年代</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%l - duration</source>
        <translation>%l - 持续时间</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - 条件</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - 向上 n 级的目录名</translation>
    </message>
</context>
</TS>
